Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2011-12-04 10:05:48 +0400
committerCampbell Barton <ideasman42@gmail.com>2011-12-04 10:05:48 +0400
commit31ff21d735cb2abeb3bee1b2efcfd49801dbb2f6 (patch)
tree00f4a63f6ee6fedf8ed2eb93046e393519a6b752 /source/blender/makesdna/DNA_world_types.h
parent3fdc28b736fc6bbdfec9075b0fdd458897786a59 (diff)
add define for deprecated DNA struct members: DNA_DEPRECATED,
this means use of deprecated struct members gives a warning. - makesdna.c preprocessor skips this. - DNA_DEPRECATED_ALLOW is used so readfile.c can do versioning without warnings. - this exposes some use of deprecated struct members, will deal with this after.
Diffstat (limited to 'source/blender/makesdna/DNA_world_types.h')
-rw-r--r--source/blender/makesdna/DNA_world_types.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/source/blender/makesdna/DNA_world_types.h b/source/blender/makesdna/DNA_world_types.h
index 0c455022db4..1e8a4574120 100644
--- a/source/blender/makesdna/DNA_world_types.h
+++ b/source/blender/makesdna/DNA_world_types.h
@@ -31,6 +31,7 @@
* \ingroup DNA
*/
+#include "DNA_defs.h"
#include "DNA_ID.h"
struct AnimData;
@@ -96,7 +97,7 @@ typedef struct World {
float misi, miststa, mistdist, misthi;
- float starr, starg, starb, stark; /* Deprecated */
+ float starr DNA_DEPRECATED, starg DNA_DEPRECATED, starb DNA_DEPRECATED, stark DNA_DEPRECATED; /* Deprecated */
float starsize, starmindist;
float stardist, starcolnoise;
@@ -119,7 +120,7 @@ typedef struct World {
float *aosphere, *aotables;
- struct Ipo *ipo; // XXX depreceated... old animation system
+ struct Ipo *ipo DNA_DEPRECATED; /* old animation system, deprecated for 2.5 */
struct MTex *mtex[18]; /* MAX_MTEX */
short pr_texture, use_nodes, pad[2];